==> MetaMax-1.6.8.tar.gz: MetaMax/method.upgrade.php <==
<?php
#-------------------------------------------------------------------------
# Module: MetaMax - an SEO your site to the Max module
# Version: 1.0, oliverseddon
# Method: Upgrade
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------

/**
 * For separated methods, you'll always want to start with the following
 * line which check to make sure that method was called from the module
 * API, and that everything's safe to continue:
*/ 
if (!isset($gCms)) exit;


/**
 * After this, the code is identical to the code that would otherwise be
 * wrapped in the Upgrade() method in the module body.
 */

$current_version = $oldversion;
switch($current_version)
{
  // we are now 1.0 and want to upgrade to latest
 case "1.0":
   //do magic
 case "1.1":
   //and this is here for the next version
 case "1.2":
 case "1.3":
 case "1.4":
 case "1.5":
 case "1.6":
 case "1.7":
 case "1.8":
	// here's an example -- we expand the MetaMax database record to include another field.
	$db = $gCms->GetDb();
	$dict = NewDataDictionary( $db );
	$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_metamax", "explanation X");
	$dict->ExecuteSQLArray($sqlarray);
}

// put mention into the admin log
$this->Audit( 0, 
	      $this->Lang('friendlyname'), 
	      $this->Lang('upgraded', $this->GetVersion()));

//note: module api handles sending generic event of module upgraded here
?>

==> MetaMax-1.9.7.tar.gz: MetaMax/method.upgrade.php <==
<?php
#-------------------------------------------------------------------------
# Module: MetaMax - an SEO your site to the Max module
# Version: 1.9.2, oliverseddon
# Method: Upgrade
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------

/**
 * For separated methods, you'll always want to start with the following
 * line which check to make sure that method was called from the module
 * API, and that everything's safe to continue:
*/ 
if (!isset($gCms)) exit;


/**
 * After this, the code is identical to the code that would otherwise be
 * wrapped in the Upgrade() method in the module body.
 */

$current_version = $oldversion;
switch($current_version)
{
  // we are now 1.0 and want to upgrade to latest
 case "1.0":
   //do magic
 case "1.1":
   //and this is here for the next version
 case "1.2":
 case "1.3":
 case "1.4":
 case "1.5":
 case "1.6.1":
 case "1.6.2":
 case "1.6.3":
 case "1.6.4":
 case "1.6.5":
 case "1.6.6":
 case "1.6.7":
 case "1.6.8":
 case "1.6.9":
 case "1.6.9.1":
 case "1.7":
 case "1.7.2":
 case "1.7.3":
 case "1.7.3.1":
 case "1.7.4":
 case "1.7.4.1":
 case "1.7.4.2":
 case "1.7.4.3":
 case "1.7.4.4":
 case "1.7.4.6":
 case "1.7.4.7":
 case "1.7.4.8":
 case "1.7.4.9.1":
 case "1.7.5":
 case "1.7.6":
 case "1.7.6.1":
 case "1.7.7":
 case "1.7.8":
 case "1.7.9":
 case "1.7.9.1":
 case "1.8":
 case "1.9.1":
 case "1.9.2":
 case "1.9.3":
 case "1.9.4":
 case "1.9.5":
 case "1.9.6":
 case "1.9.7":
}

// put mention into the admin log
$this->Audit( 0, 
	      $this->Lang('friendlyname'), 
	      $this->Lang('upgraded', $this->GetVersion()));

//note: module api handles sending generic event of module upgraded here
?>
